/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jbpm.workbench.pr.client.util;

public class LogUtils {

    public static String NODE_TYPE_HUMAN_TASK = "HumanTaskNode";
    public static String NODE_TYPE_START = "StartNode";
    public static String NODE_TYPE_END = "EndNode";
    public static String NODE_TYPE_ACTION = "ActionNode";
    public static String NODE_TYPE_MILESTONE = "MilestoneNode";
    public static String NODE_TYPE_SUBPROCESS = "SubprocessNode";
    public static String NODE_TYPE_RULE_SET = "RuleSetNode";
    public static String NODE_TYPE_WORK_ITEM = "WorkItemNode";
    public static String ALL_NODES = "All";

    public static Integer NODE_ENTERED = 0;
    public static Integer NODE_COMPLETED = 1;


}
